@@ -1,11 +1,10 @@
 import uuid
 
 import pytest
-
 from qctic.api import QCticAPI
-from qctic.backend import QCticQasmSimulator
 from qctic.job import QCticJob
 from qctic.provider import QCticProvider
+
 from tests.utils import fake_qobj
 
 
@@ -19,7 +18,7 @@ def provider(httpserver):
 
 @pytest.fixture(scope="function")
 def job(provider):
-    backend = provider.get_backend(QCticQasmSimulator.NAME)
+    backend = provider.get_backend("aer_simulator")
     job_id = str(uuid.uuid4())
     qobj = fake_qobj()
     return QCticJob(backend, job_id, qobj)
